@@ -4,14 +4,13 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-06-01'; # DATE
+our $DATE = '2024-06-12'; # DATE
 our $DIST = 'Acme-CPANAuthorsBundle-CPAN-Streaks'; # DIST
-our $VERSION = '20240601.0'; # VERSION
+our $VERSION = '20240612.0'; # VERSION
 
 use Acme::CPANAuthors::Register (
+    'TYRRMINAL' => '',
     'PERLANCAR' => '',
-    'HANJE' => '',
-    'SKIM' => '',
 );
 
 
@@ -30,20 +29,19 @@ Acme::CPANAuthors::CPAN::Streaks::DailyDistributions::Current - Authors with ong
 
 =head1 VERSION
 
-This document describes version 20240601.0 of Acme::CPANAuthors::CPAN::Streaks::DailyDistributions::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-06-01.
+This document describes version 20240612.0 of Acme::CPANAuthors::CPAN::Streaks::DailyDistributions::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-06-12.
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-Current standings (as of 2024-06-01, produced by L<cpan-streaks>):
+Current standings (as of 2024-06-12, produced by L<cpan-streaks>):
 
   +-----------+-----+------------+-------------+
   | author    | len | start_date | status      |
   +-----------+-----+------------+-------------+
-  | PERLANCAR |  47 | 2024-04-16 | ongoing     |
-  | HANJE     |   1 | 2024-05-31 | might-break |
-  | SKIM      |   1 | 2024-05-31 | might-break |
+  | TYRRMINAL |   1 | 2024-06-11 | might-break |
+  | PERLANCAR |   1 | 2024-06-12 | ongoing     |
   +-----------+-----+------------+-------------+
 
 =head1 HOMEPAGE
